==> apache-trafficcontrol-3.0.0.tar.gz: apache-trafficcontrol-3.0.0/traffic_portal/app/src/modules/private/servers/deliveryServices/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.servers.deliveryServices', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.servers.deliveryServices', {
				url: '/{serverId}/delivery-services',
				views: {
					serversContent: {
						templateUrl: 'common/modules/table/serverDeliveryServices/table.serverDeliveryServices.tpl.html',
						controller: 'TableServerDeliveryServicesController',
						resolve: {
							server: function($stateParams, serverService) {
								return serverService.getServer($stateParams.serverId);
							},
							serverDeliveryServices: function($stateParams, deliveryServiceService) {
								return deliveryServiceService.getServerDeliveryServices($stateParams.serverId);
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});

==> apache-trafficcontrol-7.0.1.tar.gz: apache-trafficcontrol-7.0.1/traffic_portal/app/src/modules/private/servers/deliveryServices/index.js <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

module.exports = angular.module('trafficPortal.private.servers.deliveryServices', [])
	.config(function($stateProvider, $urlRouterProvider) {
		$stateProvider
			.state('trafficPortal.private.servers.deliveryServices', {
				url: '/{serverId}/delivery-services',
				views: {
					serversContent: {
						templateUrl: 'common/modules/table/serverDeliveryServices/table.serverDeliveryServices.tpl.html',
						controller: 'TableServerDeliveryServicesController',
						resolve: {
							server: function($stateParams, serverService) {
								return serverService.getServers({id: $stateParams.serverId});
							},
							deliveryServices: function($stateParams, deliveryServiceService) {
								return deliveryServiceService.getServerDeliveryServices($stateParams.serverId);
							},
							filter: function() {
								return null;
							}
						}
					}
				}
			})
		;
		$urlRouterProvider.otherwise('/');
	});
